**Purpose**: Detect website content changes and perform meaningful actions - trigger notifications via Discord, Email, Slack, Telegram, API calls and many more.

## Docker Configuration
```jsx title="docker-compose.yml"
version: "3.8"
services:
  app:
    image: dgtlmoon/changedetection.io
    container_name: changedetection.io 
    environment:
      - TZ=America/Denver
    volumes:
      - /srv/containers/changedetection/datastore:/datastore
    ports:
      - 5000:5000
    restart: always
    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.changedetection.rule=Host(`changedetection.bunny-lab.io`)"
      - "traefik.http.routers.changedetection.entrypoints=websecure"
      - "traefik.http.routers.changedetection.tls.certresolver=letsencrypt"
      - "traefik.http.services.changedetection.loadbalancer.server.port=5000"
    networks:
        docker_network:
          ipv4_address: 192.168.5.49

networks:
  default:
    external:
      name: docker_network
  docker_network:
    external: true
```

```jsx title=".env"
N/A
```

## Traefik Reverse Proxy Configuration
If the container does not run on the same host as Traefik, you will need to manually add configuration to Traefik's dynamic config file, outlined below.
``` yaml
http:
  routers:
    changedetection:
      entryPoints:
        - websecure
      tls:
        certResolver: letsencrypt
      http2:
      service: changedetection
      rule: Host(`changedetection.bunny-lab.io`)

  services:
    changedetection:
      loadBalancer:
        servers:
          - url: http://192.168.5.49:5000
        passHostHeader: true
```