**Purpose**: A self-hostable personal dashboard built for you. Includes status-checking, widgets, themes, icon packs, a UI editor and tons more! 

```jsx title="docker-compose.yml"
version: "3.8"
services:
  dashy:
    container_name: Dashy

    # Pull latest image from DockerHub
    image: lissy93/dashy

    # Set port that web service will be served on. Keep container port as 80
    ports:
      - 4000:80

    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.dashy.rule=Host(`dashboard.cyberstrawberry.net`)"
      - "traefik.http.routers.dashy.entrypoints=websecure"
      - "traefik.http.routers.dashy.tls.certresolver=myresolver"
      - "traefik.http.services.dashy.loadbalancer.server.port=80"

    # Set any environmental variables
    environment:
      - NODE_ENV=production
      - UID=1000
      - GID=1000
      
    # Pass in your config file below, by specifying the path on your host machine
    volumes:
      - /srv/Containers/Dashy/conf.yml:/app/public/conf.yml
      - /srv/Containers/Dashy/item-icons:/app/public/item-icons

    # Specify restart policy
    restart: unless-stopped

    # Configure healthchecks
    healthcheck:
      test: ['CMD', 'node', '/app/services/healthcheck']
      interval: 1m30s
      timeout: 10s
      retries: 3
      start_period: 40s
      
    # Connect container to Docker_Network  
    networks:
        docker_network:
          ipv4_address: 192.168.5.57
networks:
  default:
    external:
      name: docker_network
  docker_network:
    external: true
```

```jsx title=".env"
Not Applicable
```
