**Purpose**: ONLYOFFICE offers a secure online office suite highly compatible with MS Office formats.  Generally used with Nextcloud to edit documents directly within the web browser.

```jsx title="docker-compose.yml"
version: '3'

services:
  app:
    image: onlyoffice/documentserver-ee
    ports:
      - 80:80
      - 443:443
    volumes:
      - /srv/containers/onlyoffice/DocumentServer/logs:/var/log/onlyoffice
      - /srv/containers/onlyoffice/DocumentServer/data:/var/www/onlyoffice/Data
      - /srv/containers/onlyoffice/DocumentServer/lib:/var/lib/onlyoffice
      - /srv/containers/onlyoffice/DocumentServer/db:/var/lib/postgresql
      - /srv/containers/onlyoffice/DocumentServer/fonts:/usr/share/fonts/truetype/custom
      - /srv/containers/onlyoffice/DocumentServer/forgotten:/var/lib/onlyoffice/documentserver/App_Data/cache/files/forgotten
      - /srv/containers/onlyoffice/DocumentServer/rabbitmq:/var/lib/rabbitmq
      - /srv/containers/onlyoffice/DocumentServer/redis:/var/lib/redis
    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.cyberstrawberry-onlyoffice.rule=Host(`office.cyberstrawberry.net`)"
      - "traefik.http.routers.cyberstrawberry-onlyoffice.entrypoints=websecure"
      - "traefik.http.routers.cyberstrawberry-onlyoffice.tls.certresolver=myresolver"
      - "traefik.http.services.cyberstrawberry-onlyoffice.loadbalancer.server.port=80"
      - "traefik.http.routers.cyberstrawberry-onlyoffice.middlewares=onlyoffice-headers"
      - "traefik.http.middlewares.onlyoffice-headers.headers.customrequestheaders.X-Forwarded-Proto=https"
      #- "traefik.http.middlewares.onlyoffice-headers.headers.accessControlAllowOrigin=*"
    environment:
      - JWT_ENABLED=true
      - JWT_SECRET=REDACTED #SET THIS TO SOMETHING SECURE
    restart: always
    networks:
        docker_network:
          ipv4_address: 192.168.5.143
networks:
  default:
    external:
      name: docker_network
  docker_network:
    external: true
```

```jsx title=".env"
Not Applicable
```
:::tip
If you wish to use this in a non-commercial homelab environment without limits, [this script](https://wiki.muwahhid.ru/ru/Unraid/Docker/Onlyoffice-Document-Server) does an endless trial without functionality limits.
```
docker stop office-document-server-ee
docker rm office-document-server-ee
rm -r /mnt/user/appdata/onlyoffice/DocumentServer
sleep 5
<USE A PORTAINER WEBHOOK TO RECREATE THE CONTAINER OR REFERENCE THE DOCKER RUN METHOD BELOW>
```

Docker Run Method:
```
docker run -d --name='office-document-server-ee' --net='bridge' -e TZ="Europe/Moscow" -e HOST_OS="Unraid" -e 'JWT_ENABLED'='true' -e 'JWT_SECRET'='mySecret' -p '8082:80/tcp' -p '4432:443/tcp' -v '/mnt/user/appdata/onlyoffice/DocumentServer/logs':'/var/log/onlyoffice':'rw' -v '/mnt/user/appdata/onlyoffice/DocumentServer/data':'/var/www/onlyoffice/Data':'rw' -v '/mnt/user/appdata/onlyoffice/DocumentServer/lib':'/var/lib/onlyoffice':'rw' -v '/mnt/user/appdata/onlyoffice/DocumentServer/db':'/var/lib/postgresql':'rw' -v '/mnt/user/appdata/onlyoffice/DocumentServer/fonts':'/usr/share/fonts/truetype/custom':'rw' -v '/mnt/user/appdata/onlyoffice/DocumentServer/forgotten':'/var/lib/onlyoffice/documentserver/App_Data/cache/files/forgotten':'rw' -v '/mnt/user/appdata/onlyoffice/DocumentServer/rabbitmq':'/var/lib/rabbitmq':'rw' -v '/mnt/user/appdata/onlyoffice/DocumentServer/redis':'/var/lib/redis':'rw' 'onlyoffice/documentserver-ee'
```
:::

