**Purpose**: An application to securely communicate passwords over the web. Passwords automatically expire after a certain number of views and/or time has passed. Track who, what and when. 

## Docker Configuration
```jsx title="docker-compose.yml"
version: '3'

services:
  passwordpusher:
    image: docker.io/pglombardo/pwpush:release
    expose:
      - 5100
    restart: always
    environment:
      # Read Documention on how to generate a master key, then put it below
      - PWPUSH_MASTER_KEY=${PWPUSH_MASTER_KEY}
    networks:
        docker_network:
          ipv4_address: 192.168.5.170
    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.passwordpusher.rule=Host(`temp.bunny-lab.io`)"
      - "traefik.http.routers.passwordpusher.entrypoints=websecure"
      - "traefik.http.routers.passwordpusher.tls.certresolver=letsencrypt"
      - "traefik.http.services.passwordpusher.loadbalancer.server.port=5100"
networks:
  docker_network:
    external: true
```

```jsx title=".env"
PWPUSH_MASTER_KEY=<PASSWORD>
```

!!! note "PWPUSH_MASTER_KEY"
    Generate a master key by visiting the [official online key generator](https://pwpush.com/en/pages/generate_key).

## Traefik Reverse Proxy Configuration
If the container does not run on the same host as Traefik, you will need to manually add configuration to Traefik's dynamic config file, outlined below.
``` yaml
http:
  routers:
    password-pusher:
      entryPoints:
        - websecure
      tls:
        certResolver: letsencrypt
      service: password-pusher
      rule: Host(`temp.bunny-lab.io`)

  services:
    password-pusher:
      loadBalancer:
        servers:
          - url: http://192.168.5.170:5100
        passHostHeader: true
```